class Voyager {
    constructor({ selector = "[data-voyager]", activeClass = "active", rootMarginTop = "0px", rootMarginBottom = "0px", threshold = 0.1 } = {}) {
        this.observer = null;
        this._links = null;
        this.selector = selector;
        this.activeClass = activeClass;
        this.rootMarginTop = rootMarginTop;
        this.rootMarginBottom = rootMarginBottom;
        this.threshold = threshold;
        this.refresh();
    }
    /**
     * Refresh the intersection observer and re-initialize it.
     */
    refresh() {
        this._links = document.querySelectorAll(`${this.selector} a`);
        if ("IntersectionObserver" in window && this._links.length > 0) {
            this.observer = new IntersectionObserver(this._handleIntersect.bind(this), {
                rootMargin: `${this.rootMarginTop} 0px ${this.rootMarginBottom} 0px`,
                threshold: this.threshold,
            });
            this._links.forEach((link) => {
                var _a;
                link.addEventListener("click", (event) => {
                    event.preventDefault();
                    const targetId = link.getAttribute("href");
                    const targetElement = document.querySelector(targetId);
                    targetElement === null || targetElement === void 0 ? void 0 : targetElement.scrollIntoView({ behavior: "smooth" });
                });
                const target = document.querySelector(link.hash);
                if (target) {
                    (_a = this.observer) === null || _a === void 0 ? void 0 : _a.observe(target);
                }
            });
        }
    }
    /**
     * Handles the intersection of observed elements.
     */
    _handleIntersect(entries) {
        entries.forEach((entry) => {
            const id = `#${entry.target.getAttribute("id")}`;
            const anchor = document.querySelector(`[href="${id}"]`);
            if (entry.isIntersecting) {
                document.querySelectorAll(`.${this.activeClass}`).forEach((el) => el.classList.remove(this.activeClass));
                anchor === null || anchor === void 0 ? void 0 : anchor.classList.add(this.activeClass);
            }
        });
    }
    /**
     * Destroys the observer and clears properties.
     */
    destroy() {
        if (this.observer) {
            this.observer.disconnect();
            this.observer = null;
        }
        this._links = null;
    }
}
export default Voyager;
